@@ -34,7 +34,7 @@ from tinydav.exception import HTTPError, HTTPUserError, HTTPServerError
 
 __author__ = "Manuel Hermann <manuel-hermann@gmx.net>"
 __license__ = "LGPL"
-__version__ = "0.6.4"
+__version__ = "0.6.5"
 
 __all__ = (
     "HTTPError", "HTTPUserError", "HTTPServerError",
@@ -115,7 +115,7 @@ class HTTPResponse(int):
         self.nonce = auth.get("nonce")
         self.opaque = auth.get("opaque")
         stale = auth.get("stale", "false")
-        self.stale = (state.lower() == "true")
+        self.stale = (stale.lower() == "true")
         algorithm = auth.get("algoritm", "MD5")
         self.algorithm = getattr(hashlib, algorithm.lower())
 
